@@ -1,9 +1,11 @@
-package Dist::Zilla::Role::ShareDir 6.017;
+package Dist::Zilla::Role::ShareDir 6.030;
 # ABSTRACT: something that picks a directory to install as shared files
 
 use Moose::Role;
 with 'Dist::Zilla::Role::FileFinder';
 
+use Dist::Zilla::Pragmas;
+
 use namespace::autoclean;
 
 # Must return a hashref with any of the keys 'dist' and 'module'.  The 'dist'
@@ -26,15 +28,27 @@ Dist::Zilla::Role::ShareDir - something that picks a directory to install as sha
 
 =head1 VERSION
 
-version 6.017
+version 6.030
+
+=head1 PERL VERSION
+
+This module should work on any version of perl still receiving updates from
+the Perl 5 Porters.  This means it should work on any version of perl released
+in the last two to three years.  (That is, if the most recently released
+version is v5.40, then this module should work on both v5.40 and v5.38.)
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
 
 =head1 AUTHOR
 
-Ricardo SIGNES 😏 <rjbs@cpan.org>
+Ricardo SIGNES 😏 <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Ricardo SIGNES.
+This software is copyright (c) 2023 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
